@@ -481,7 +481,7 @@ class RabbitMQClient:
                                 await self.stop_consuming()
                                 await asyncio.sleep(1)
                                 await self.start_consuming()
-                                logger.info("消费者已重启以恢复消费")
+                                # logger.info("消费者已重启以恢复消费")
                 except Exception as e:
                     logger.error(f"监控任务出错: {str(e)}")
                     await asyncio.sleep(1)
